==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebForOfStateEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfStateDetailDescriptionMetadata } from "./WebForOfStateDetailDescriptionMetadata";
import { WebForOfStateEventArgsDescription } from "./WebForOfStateEventArgsDescription";
/**
 * @hidden
 */
export let WebForOfStateEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebForOfStateEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebForOfStateEventArgsDescriptionMetadata.a == null) {
                WebForOfStateEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebForOfStateEventArgsDescriptionMetadata.c(WebForOfStateEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebForOfStateEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebForOfStateEventArgsDescriptionMetadata.a);
            WebForOfStateDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ForOfStateEventArgs");
            a.item("Detail", "ExportedType:WebForOfStateDetail");
        }
        static d(a) {
            WebForOfStateEventArgsDescriptionMetadata.b(a);
            a.aa("WebForOfStateEventArgs", () => new WebForOfStateEventArgsDescription());
            a.z("WebForOfStateEventArgs", WebForOfStateEventArgsDescriptionMetadata.a);
        }
    }
    WebForOfStateEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebForOfStateEventArgsDescriptionMetadata, 'WebForOfStateEventArgsDescriptionMetadata');
    WebForOfStateEventArgsDescriptionMetadata.a = null;
    return WebForOfStateEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebForOfStateEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfStateDetailDescriptionMetadata } from "./WebForOfStateDetailDescriptionMetadata";
import { WebForOfStateEventArgsDescription } from "./WebForOfStateEventArgsDescription";
/**
 * @hidden
 */
export let WebForOfStateEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebForOfStateEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebForOfStateEventArgsDescriptionMetadata.a == null) {
                WebForOfStateEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebForOfStateEventArgsDescriptionMetadata.c(WebForOfStateEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebForOfStateEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebForOfStateEventArgsDescriptionMetadata.a);
            WebForOfStateDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ForOfStateEventArgs");
            a.item("Detail", "ExportedType:WebForOfStateDetail");
        }
        static d(a) {
            WebForOfStateEventArgsDescriptionMetadata.b(a);
            a.ac("WebForOfStateEventArgs", () => new WebForOfStateEventArgsDescription());
            a.ab("WebForOfStateEventArgs", WebForOfStateEventArgsDescriptionMetadata.a);
        }
    }
    WebForOfStateEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebForOfStateEventArgsDescriptionMetadata, 'WebForOfStateEventArgsDescriptionMetadata');
    WebForOfStateEventArgsDescriptionMetadata.a = null;
    return WebForOfStateEventArgsDescriptionMetadata;
})();
